;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "flymake-x" "20251020.2034"
  "Simple flymake checker definitions."
  '((emacs   "28.1")
    (flymake "1.0"))
  :url "https://github.com/mkcms/flymake-x"
  :commit "5476c4d1ff2539da0f9335615678f938b4da95df"
  :revdesc "5476c4d1ff25"
  :keywords '("languages" "tools")
  :authors '(("Michał Krzywkowski" . "k.michal@zoho.com"))
  :maintainers '(("Michał Krzywkowski" . "k.michal@zoho.com")))
